.. _`pip show`:

pip show
--------

.. contents::

Usage
*****

.. pip-command-usage:: show

Description
***********

.. pip-command-description:: show


Options
*******

.. pip-command-options:: show


Examples
********

#. Show information about a package:

    ::

      $ pip show sphinx
      ---
      Name: Sphinx
      Version: 1.1.3
      Location: /my/env/lib/pythonx.x/site-packages
      Requires: Pygments, Jinja2, docutils
